@@ -2,10 +2,12 @@ from .QPythonHighlighter import QPythonHighlighter
 from .QJSONHighlighter import QJSONHighlighter
 from .QCXXHighlighter import QCXXHighlighter
 from .QLuaHighlighter import QLuaHighlighter
+from .QGLSLHighlighter import QGLSLHighlighter
 
 __all__ = [
     "QPythonHighlighter",
     "QJSONHighlighter",
     "QCXXHighlighter",
     "QLuaHighlighter",
+    "QGLSLHighlighter",
 ]
